package com.qmth.sop.server.api;

import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.sop.business.activiti.service.ActivitiService;
import com.qmth.sop.business.bean.params.FlowApproveParam;
import com.qmth.sop.business.bean.params.SopAllocationParam;
import com.qmth.sop.business.bean.params.SopInfoListParam;
import com.qmth.sop.business.bean.params.SopSaveParam;
import com.qmth.sop.business.bean.result.FlowResult;
import com.qmth.sop.business.bean.result.FormWidgetMetadataResult;
import com.qmth.sop.business.entity.SysUser;
import com.qmth.sop.business.entity.TDFormWidgetMetadata;
import com.qmth.sop.business.service.TBSopInfoService;
import com.qmth.sop.business.service.TDFormWidgetMetadataService;
import com.qmth.sop.common.annotation.OperationLog;
import com.qmth.sop.common.contant.SystemConstant;
import com.qmth.sop.common.enums.ExceptionResultEnum;
import com.qmth.sop.common.enums.LogTypeEnum;
import com.qmth.sop.common.enums.TFCustomTypeEnum;
import com.qmth.sop.common.util.JacksonUtil;
import com.qmth.sop.common.util.Result;
import com.qmth.sop.common.util.ResultUtil;
import io.swagger.annotations.*;
import org.springframework.util.CollectionUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * sop表 前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2023-08-01
 */
@Api(tags = "sop管理Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_SOP)
public class TBSopInfoController {

    @Resource
    TDFormWidgetMetadataService tdFormWidgetMetadataService;

    @Resource
    TBSopInfoService tbSopInfoService;

    @Resource
    ActivitiService activitiService;

    @ApiOperation(value = "sop元数据查询")
    @RequestMapping(value = "/metadata/list", method = RequestMethod.POST)
    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = FormWidgetMetadataResult.class) })
    public Result metadataList(@ApiParam(value = "sop流程类型", required = true) @RequestParam TFCustomTypeEnum type) {
        return ResultUtil.ok(tdFormWidgetMetadataService.selectAll(type));
    }

    @ApiOperation(value = "sop元数据修改")
    @RequestMapping(value = "/metadata/save", method = RequestMethod.POST)
    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = Object.class) })
    @OperationLog(logType = LogTypeEnum.UPDATE)
    public Result metadataSave(
            @Valid @ApiParam(value = "元数据保存信息", required = true) @RequestBody List<TDFormWidgetMetadata> formWidgetMetadataList,
            BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        return ResultUtil.ok(tdFormWidgetMetadataService.save(formWidgetMetadataList));
    }

    //    @ApiOperation(value = "sop申请")
    //    @RequestMapping(value = "/apply", method = RequestMethod.POST)
    //    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = Object.class) })
    //    @OperationLog(logType = LogTypeEnum.UN_KNOW)
    //    public Result apply(@Valid @ApiParam(value = "sop申请信息", required = true) @RequestBody SopApplyParam sopApplyParam,
    //            BindingResult bindingResult) throws InterruptedException {
    //        if (bindingResult.hasErrors()) {
    //            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
    //        }
    //        return ResultUtil.ok(tbSopInfoService.sopApply(sopApplyParam));
    //    }

    @ApiOperation(value = "sop填报")
    @RequestMapping(value = "/approve", method = RequestMethod.POST)
    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = Object.class) })
    @OperationLog(logType = LogTypeEnum.UN_KNOW)
    public Result approve(
            @Valid @ApiParam(value = "sop填报信息", required = true) @RequestBody FlowApproveParam flowApproveParam,
            BindingResult bindingResult) throws InterruptedException {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        return ResultUtil.ok(tbSopInfoService.sopApprove(flowApproveParam));
    }

    @ApiOperation(value = "sop列表接口")
    @RequestMapping(value = "/list", method = RequestMethod.POST)
    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = Map.class) })
    public Result list(
            @Valid @ApiParam(value = "sop列表信息", required = true) @RequestBody SopInfoListParam sopInfoListParam,
            BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        return ResultUtil.ok(tbSopInfoService.list(sopInfoListParam));
    }

    @ApiOperation(value = "sop人员配置")
    @RequestMapping(value = "/allocation", method = RequestMethod.POST)
    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = Object.class) })
    public Result allocation(@Valid @RequestBody SopAllocationParam sopAllocationParam, BindingResult bindingResult)
            throws InterruptedException {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        return ResultUtil.ok(tbSopInfoService.sopAllocation(sopAllocationParam));
    }

    @ApiOperation(value = "sop删除")
    @RequestMapping(value = "/cancel", method = RequestMethod.POST)
    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = Object.class) })
    @OperationLog(logType = LogTypeEnum.DELETE)
    public Result cancel(@ApiParam(value = "流程id", required = true) @RequestParam Long flowId) {
        return ResultUtil.ok(activitiService.flowEnd(flowId));
    }

    @ApiOperation(value = "sop批量删除")
    @RequestMapping(value = "/batch/cancel", method = RequestMethod.POST)
    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = Object.class) })
    @OperationLog(logType = LogTypeEnum.DELETE)
    public Result batchCancel(@ApiParam(value = "流程id数组", required = true) @RequestBody List<Long> flowIds) {
        if (CollectionUtils.isEmpty(flowIds)) {
            throw ExceptionResultEnum.ERROR.exception("流程id数组不能为空");
        }
        for (Long l : flowIds) {
            activitiService.flowEnd(l);
        }
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "sop编辑")
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = FlowResult.class) })
    @OperationLog(logType = LogTypeEnum.EDIT)
    public Result edit(@ApiParam(value = "sopId", required = true) @RequestParam Long id) throws InterruptedException {
        return ResultUtil.ok(tbSopInfoService.sopEdit(id));
    }

    @ApiOperation(value = "sop保存")
    @RequestMapping(value = "/save", method = RequestMethod.POST)
    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = Object.class) })
    @OperationLog(logType = LogTypeEnum.EDIT)
    public Result save(@Valid @ApiParam(value = "sop保存信息", required = true) @RequestBody SopSaveParam sopSaveParam,
            BindingResult bindingResult) throws InterruptedException {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        return ResultUtil.ok(tbSopInfoService.sopSave(sopSaveParam));
    }

    @ApiOperation(value = "sopUsers")
    @RequestMapping(value = "/user/list", method = RequestMethod.POST)
    @ApiResponses({ @ApiResponse(code = 200, message = "返回信息", response = SysUser.class) })
    public Result userList(@ApiParam(value = "sopId", required = true) @RequestParam Long sop_info_id) {
        //        return ResultUtil.ok(tbSopInfoService.userList(sop_info_id));
        return ResultUtil.ok(true);
    }

    public static void main(String[] args) {
        String s = "{\"taskName\":\"项目确认\",\"taskKey\":\"f_usertask_office_first_1\",\"setup\":1,\"formKey\":\"office_sop_first.form\",\"formProperty\":[{\"id\":\"18\",\"code\":\"RADIO\",\"type\":\"FORM\",\"formId\":\"service_scope_radio_1\",\"formName\":\"service_scope_radio_1\",\"title\":\"服务范围\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"value\":\"{\\\"value\\\":\\\"SCAN_MARK\\\"}\",\"name\":\"单选框\",\"span\":6,\"options\":\"[{\\\"value\\\":\\\"SCAN\\\",\\\"label\\\":\\\"仅扫描\\\"},{\\\"value\\\":\\\"SCAN_MARK\\\",\\\"label\\\":\\\"扫描+阅卷\\\"}]\"},{\"id\":\"19\",\"code\":\"RADIO\",\"type\":\"FORM\",\"formId\":\"deploy_way_radio_1\",\"formName\":\"deploy_way_radio_1\",\"title\":\"部署方式\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"{\\\"value\\\":\\\"LOCAL\\\"}\",\"name\":\"单选框\",\"span\":6,\"options\":\"[{\\\"value\\\":\\\"ONLINE\\\",\\\"label\\\":\\\"线上部署\\\"},{\\\"value\\\":\\\"LOCAL\\\",\\\"label\\\":\\\"本地部署\\\"}]\",\"formGroup\":1000},{\"id\":\"20\",\"code\":\"RADIO\",\"type\":\"FORM\",\"formId\":\"mark_way_radio_1\",\"formName\":\"mark_way_radio_1\",\"title\":\"阅卷方式\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"{\\\"value\\\":\\\"TOGETHER\\\"}\",\"name\":\"单选框\",\"span\":6,\"options\":\"[{\\\"value\\\":\\\"TOGETHER\\\",\\\"label\\\":\\\"集中阅卷\\\"},{\\\"value\\\":\\\"ANYTIME\\\",\\\"label\\\":\\\"分散阅卷\\\"}]\",\"formGroup\":1000},{\"id\":\"21\",\"code\":\"RADIO\",\"type\":\"FORM\",\"formId\":\"scan_net_radio_1\",\"formName\":\"scan_net_radio_1\",\"title\":\"扫描场地网络情况\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"{\\\"value\\\":\\\"INTERNET\\\"}\",\"name\":\"单选框\",\"span\":6,\"options\":\"[{\\\"value\\\":\\\"INTERNET\\\",\\\"label\\\":\\\"提供外网\\\"},{\\\"value\\\":\\\"LOCALHOST\\\",\\\"label\\\":\\\"不提供外网\\\"}]\",\"formGroup\":1000},{\"id\":\"22\",\"code\":\"TEXT\",\"type\":\"FORM\",\"formId\":\"contacts_1\",\"formName\":\"contacts_1\",\"title\":\"联系人\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"value\":\"{\\\"value\\\":\\\"66\\\"}\",\"name\":\"文本\",\"span\":6},{\"id\":\"23\",\"code\":\"TEXT\",\"type\":\"FORM\",\"formId\":\"mobile_number_1\",\"formName\":\"mobile_number_1\",\"title\":\"电话\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"value\":\"{\\\"value\\\":\\\"77\\\"}\",\"name\":\"文本\",\"span\":6},{\"id\":\"24\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"scan_start_time_1\",\"formName\":\"scan_start_time_1\",\"title\":\"扫描开始时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"{\\\"value\\\":1716393600000}\",\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"25\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"scan_end_time_1\",\"formName\":\"scan_end_time_1\",\"title\":\"扫描结束时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"{\\\"value\\\":1716480000000}\",\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"26\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"mark_start_time_1\",\"formName\":\"mark_start_time_1\",\"title\":\"阅卷参数检查时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"{\\\"value\\\":1716566400000}\",\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"27\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"mark_end_time_1\",\"formName\":\"mark_end_time_1\",\"title\":\"阅卷收尾检查时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"{\\\"value\\\":1716652800000}\",\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"28\",\"code\":\"MULTIPLE_SELECT\",\"type\":\"FORM\",\"formId\":\"engineer_users_id_1\",\"formName\":\"engineer_users_id_1\",\"title\":\"工程师\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"{\\\"value\\\":[\\\"517334446353940480\\\"]}\",\"dataGrid\":\"/api/admin/user/archives/allocation/can_choose?crmDetailId=#{id}&sopRoleType=ENGINEER\",\"name\":\"多选下拉框\",\"span\":12},{\"id\":\"29\",\"code\":\"SIGN\",\"type\":\"FORM\",\"formId\":\"sign_region_1\",\"formName\":\"sign_region_1\",\"title\":\"添加签名\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"签名\",\"span\":6}],\"approveRejectList\":null}";
        //        String s = "{\"taskName\":\"扫描准备\",\"taskKey\":\"f_usertask_office_scan_ready_2\",\"setup\":2,\"formKey\":\"office_sop_scan_ready.form\",\"formProperty\":[{\"id\":\"30\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"import_data_title_2\",\"formName\":\"import_data_title_2\",\"title\":\"导入数据\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"31\",\"code\":\"CHECKBOX\",\"type\":\"FORM\",\"formId\":\"data_same_2\",\"formName\":\"data_same_2\",\"title\":\"导入数据\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"复选框\",\"span\":6,\"options\":\"[{\\\"value\\\":\\\"true\\\",\\\"label\\\":\\\"导入数据与原始数据是否一致\\\"}]\"},{\"id\":\"32\",\"code\":\"NUMBER\",\"type\":\"FORM\",\"formId\":\"import_exam_student_count_2\",\"formName\":\"import_exam_student_count_2\",\"title\":\"导入考生数量\",\"inputType\":\"INT\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"数字文本\",\"span\":6},{\"id\":\"33\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"scan_set_title_2\",\"formName\":\"scan_set_title_2\",\"title\":\"扫描仪设置\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"34\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"scan_set_2\",\"formName\":\"scan_set_2\",\"title\":\"扫描仪设置\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12},{\"id\":\"35\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"scan_test_title_2\",\"formName\":\"scan_test_title_2\",\"title\":\"试扫检查\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"36\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"scan_test_2\",\"formName\":\"scan_test_2\",\"title\":\"试扫检查\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12}],\"approveRejectList\":null}";
        //        String s = "{\"taskName\":\"扫描收尾检查\",\"taskKey\":\"f_usertask_office_scan_end_3\",\"setup\":3,\"formKey\":\"office_sop_scan_end.form\",\"formProperty\":[{\"id\":\"37\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"scan_end_title_3\",\"formName\":\"scan_end_title_3\",\"title\":\"扫描收尾检查\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"38\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"scan_end_3\",\"formName\":\"scan_end_3\",\"title\":\"扫描收尾检查\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12},{\"id\":\"39\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"not_upload_confirm_title_3\",\"formName\":\"not_upload_confirm_title_3\",\"title\":\"未上传确认\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"40\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"not_upload_confirm_3\",\"formName\":\"not_upload_confirm_3\",\"title\":\"未上传确认\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12},{\"id\":\"41\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"identify_title_3\",\"formName\":\"identify_title_3\",\"title\":\"识别对照\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"42\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"identify_3\",\"formName\":\"identify_3\",\"title\":\"识别对照\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12},{\"id\":\"43\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"absent_title_3\",\"formName\":\"absent_title_3\",\"title\":\"缺考识别检查\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"44\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"absent_3\",\"formName\":\"absent_3\",\"title\":\"缺考识别检查\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12},{\"id\":\"45\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"manual_confirm_title_3\",\"formName\":\"manual_confirm_title_3\",\"title\":\"人工确认检查\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"46\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"manual_confirm_3\",\"formName\":\"manual_confirm_3\",\"title\":\"人工确认检查\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12}],\"approveRejectList\":null}";
        //        String s = "{\"taskName\":\"阅卷参数检查\",\"taskKey\":\"f_usertask_office_mark_paper_4\",\"setup\":4,\"formKey\":\"office_sop_mark_paper.form\",\"formProperty\":[{\"id\":\"47\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"mark_paper_title_4\",\"formName\":\"mark_paper_title_4\",\"title\":\"阅卷参数检查\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"48\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"mark_paper_4\",\"formName\":\"mark_paper_4\",\"title\":\"阅卷参数检查\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12}],\"approveRejectList\":null}";
        //        String s = "{\"taskName\":\"阅卷收尾检查\",\"taskKeyq\":\"f_usertask_office_mark_paper_end_5\",\"setup\":5,\"formKey\":\"office_sop_mark_paper_end.form\",\"formProperty\":[{\"id\":\"49\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"mark_paper_progress_title_5\",\"formName\":\"mark_paper_progress_title_5\",\"title\":\"阅卷进度检查\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"50\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"mark_paper_progress_5\",\"formName\":\"mark_paper_progress_5\",\"title\":\"阅卷进度检查\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12},{\"id\":\"51\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"objective_check_title_5\",\"formName\":\"objective_check_title_5\",\"title\":\"实考客观题0分检查\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"52\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"objective_check_5\",\"formName\":\"objective_check_5\",\"title\":\"实考客观题0分检查\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12},{\"id\":\"53\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"subjective_check_title_5\",\"formName\":\"subjective_check_title_5\",\"title\":\"实考主观题0分，客观题有分\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"54\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"subjective_check_5\",\"formName\":\"subjective_check_5\",\"title\":\"实考主观题0分，客观题有分\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文件\",\"span\":12}],\"approveRejectList\":null}";
        System.out.println(JacksonUtil.parseJson(s));
    }
}